ContractMethod class final

One parsed contract method: signIn(email, password) -> User.

Constructors

ContractMethod({required String name, required List<String> params, required String returns})
const
ContractMethod.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
final
params List<String>
final
returns String
The declared return type name (User, void, SyncResult, ...).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override