DeclaredTouchpointRow class final
One declared dependency row consumed from the spec's External Dependencies & Contracts table (#960's output shape).
Constructors
- DeclaredTouchpointRow({required String name, required String type, required String contract, required String priority})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited