LatencySample class final

One drawn latency: the milliseconds and the band they came from.

Constructors

LatencySample(int ms, LatencyBand band)
const

Properties

band LatencyBand
final
hashCode int
The hash code for this object.
no setterinherited
ms int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited