RetrySyncEngine class final

The retry-with-backoff sync engine (the temporal demo feature).

Constructors

RetrySyncEngine({required VirtualClock clock, required RetryPolicy policy})

Properties

clock VirtualClock
The world's virtual clock: backoff waits advance it.
final
hashCode int
The hash code for this object.
no setterinherited
policy RetryPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync(String behavior, Future operation()) Future<SyncOutcome>
Sync operation (a touchpoint invocation) under the retry policy.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited