world property

SimulationWorld? world
final

The certified simulation world bound to the container, when the feature fixtures directory carried certified families (#832).

Implementation

final SimulationWorld? world;