SimulationFlavor class final
Compile-time flavor introspection for the simulation mode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkFlagConflicts(
{bool simulation = kSimulationMode, bool realBackend = kRealBackendMode}) → void - Whether the compile-time flag set is coherent.
-
describe(
) → String -
The flavor name:
simulationwhen compiled with--dart-define=SIMULATION=true, otherwisereal.