StormFailure class final

One fired storm's resolved failure.

Constructors

StormFailure({required WorldStorm storm, required StormFailureKind kind})
const

Properties

authCode → String
The auth error code when kind is StormFailureKind.auth.
no setter
hashCode → int
The hash code for this object.
no setterinherited
httpStatus → int
The HTTP status when kind is StormFailureKind.http.
no setter
kind → StormFailureKind
final
label → String
Human-readable classification for ledgers and receipts.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storm → WorldStorm
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

kindOf(Map<String, dynamic> failure) → StormFailureKind