SyncFailure class final

One recorded failure in the sync's ledger.

Constructors

SyncFailure(String kind, String label, {required int atAttempt})
const

Properties

atAttempt → int
The attempt (1-based) the failure occurred on.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String
http | timeout | partial | auth | unknown.
final
label → String
The classified label (http-503, auth-user-token-expired, partial-write).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited