VirtualClock.atEpoch constructor
VirtualClock.atEpoch(
- int epochMs
Construct a clock pinned to an explicit epoch (tests).
Implementation
VirtualClock.atEpoch(this.epochMs) : _nowMs = epochMs;
Construct a clock pinned to an explicit epoch (tests).
VirtualClock.atEpoch(this.epochMs) : _nowMs = epochMs;