WorldCertification class final

The certification outcome for one world.

Constructors

WorldCertification({required String scenario, required String worldHash, required bool certified, required List<WorldMethodProof> proofs, required String at})
const

Properties

at → String
ISO-8601 UTC — when the LIVE proof executed.
final
certified → bool
final
hashCode → int
The hash code for this object.
no setterinherited
proofs → List<WorldMethodProof>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenario → String
final
worldHash → String
The certified world's hash (binds the receipt to the exact world version).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() → Map<String, dynamic>
toFileContents() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited