WorldDifferentialResult class final

The differential run's result.

Constructors

WorldDifferentialResult({required WorldDiffVerdict verdict, required List<WorldDiffRow> rows, required List<String> unrehearsedStorms, String? worldHash})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rows → List<WorldDiffRow>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unrehearsedStorms → List<String>
Declared storms that never fired across the world run.
final
verdict → WorldDiffVerdict
final
worldHash → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited