WorldManifestError class final

Raised when a world manifest is structurally invalid. The message carries the machine-actionable --> fix: line (errors-are-an-API).

Implemented types
Available extensions

Constructors

WorldManifestError(String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFailure([StackTrace? stackTrace]) AppFailure

Available on Exception, provided by the ExceptionToFailure extension

Convert this exception to an AppFailure
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited