WorldPlay class final

One recorded invocation (the play ledger entry).

Constructors

WorldPlay({required String behavior, required String touchpoint, required String method, required int call, required int latencyMs, required String band, required int virtualMs, required String outcome, required String detail})
const

Properties

band → String
final
behavior → String
final
call → int
final
detail → String
final
hashCode → int
The hash code for this object.
no setterinherited
latencyMs → int
final
method → String
final
outcome → String
ok | failure | partial.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
touchpoint → String
final
virtualMs → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited