worldValid property
Whether the receipt is still a valid proof (false = the world
mutated and the receipt was invalidated).
Implementation
final bool worldValid;
Whether the receipt is still a valid proof (false = the world
mutated and the receipt was invalidated).
final bool worldValid;