ContractState class

states[] — one view's declared state handling.

Constructors

ContractState({required String view, required bool loading, required String error, required bool empty})
const

Properties

empty → bool
final
error → String
final
hashCode → int
The hash code for this object.
no setteroverride
loading → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fields → const List<SkinContractFieldSpec>