ContractStateRow class

stateRows[] — one audit-row declaration for the runtime kit.

Constructors

ContractStateRow({required String view, required String row, required String kind})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
kind → String
final
row → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fields → const List<SkinContractFieldSpec>