SkinContractDeclaration class

A parsed ## Skin Contract: <name> declaration: the heading name plus the parsed body. The name is declaration metadata — it never enters the JSON schema.

Constructors

SkinContractDeclaration({required String name, required SkinContract contract})
const

Properties

contract SkinContract
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited