declaredRoutes property
The declared (path → view) pairs in contract order — what the shell needs to populate its route table.
Implementation
final List<ContractRoute> declaredRoutes;
The declared (path → view) pairs in contract order — what the shell needs to populate its route table.
final List<ContractRoute> declaredRoutes;