command property
Whitespace-tokenized command; executed WITHOUT a shell; the first token must be in the session allowlist.
Implementation
final String command;
Whitespace-tokenized command; executed WITHOUT a shell; the first token must be in the session allowlist.
final String command;