ScriptedZapStepExecutor class

Deterministic executor for tests and the conformance suite.

Inheritance

Constructors

ScriptedZapStepExecutor(Future<ZapStepRun> handler(MissionStep step))

Properties

handler → Future<ZapStepRun> Function(MissionStep step)
stepId → run result (or throw to simulate a broken executor).
final
hashCode → int
The hash code for this object.
no setterinherited
invoked → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(MissionStep step, {required String workingDirectory, required Duration timeout}) → Future<ZapStepRun>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited