SubprocessZapStepExecutor class

The production executor: real subprocess, no shell.

Inheritance

Constructors

SubprocessZapStepExecutor()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(MissionStep step, {required String workingDirectory, required Duration timeout}) Future<ZapStepRun>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited