ZapConformanceReport class

The suite's verdict.

Constructors

ZapConformanceReport(List<ZapConformanceCheck> checks)
const

Properties

checks → List<ZapConformanceCheck>
final
failed → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
ok → bool
no setter
passed → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited