ZapSession class

One session's certified state.

Constructors

ZapSession({required String missionId, required int budget, required String riskTier, required List<String> toolAllowlist})

Properties

budget → int
final
evidence → List<Map<String, Object?>>
Certified evidence facts, in execution order (chain input).
final
hashCode → int
The hash code for this object.
no setterinherited
missionId → String
final
riskTier → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepsExecuted → int
no setter
stepsTotal ↔ int
Steps accepted (requested) across missions.
getter/setter pair
toolAllowlist → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromSnapshot(Map<String, Object?> snap) → ZapSession