ZapValidationResult class

The outcome of validating one document.

Constructors

ZapValidationResult({required List<ZapValidationIssue> issues})
const
ZapValidationResult.ok()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
issues → List<ZapValidationIssue>
final
ok → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited