zapTimeoutExit top-level constant
int
const zapTimeoutExit
The exit code convention for a step killed by its timeout.
Implementation
const int zapTimeoutExit = 124;
The exit code convention for a step killed by its timeout.
const int zapTimeoutExit = 124;