$CreateParams<T> class abstract

Parameters for creating a new entity of type T.

The type parameter T represents the entity type being created.

Implemented types
Annotations
  • @Zorphy(generateJson: true, generateFilter: true)

Constructors

$CreateParams()
const

Properties

data → T
The entity data to create.
no setter
hashCode int
The hash code for this object.
no setterinherited
params Map<String, dynamic>?
Optional additional parameters.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited