ASTScanner class

Scans a Dart project for all decorator annotations and produces ScanResults containing MethodAST + DecoratorAST pairs.

Constructors

ASTScanner({required String projectRoot, List<String> includeGlobs = const ['**/*.dart'], List<String> excludeGlobs = const ['**/*.g.dart', '**/*.freezed.dart']})

Properties

excludeGlobs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
includeGlobs List<String>
final
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan() Future<List<ScanResult>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited