AgentInternal class

Sugar for @AgentRisk(AgentRiskTier.admin).

Marks the entity/usecase as internal: restricted to admin users and excluded from public manifests.

@AgentInternal
@zorphy
abstract class $SystemConfig { ... }

Constructors

AgentInternal()
Creates an agent-internal annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited