AppRestartCachePolicy class

App restart cache policy.

Caches are valid only for the current app session. All caches are invalidated when the app restarts.

Example

final policy = AppRestartCachePolicy();
if (await policy.isValid('configs')) {
  // Use cached data
} else {
  // Fetch fresh data
  await policy.markFresh('configs');
}
Implemented types

Constructors

AppRestartCachePolicy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all cached data.
override
invalidate(String key) Future<void>
Invalidate cached data for key.
override
isValid(String key) Future<bool>
Check if cached data for key is still valid.
override
markFresh(String key) Future<void>
Mark cached data for key as fresh.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited