AppendExecutor class

Constructors

AppendExecutor({List<AppendStrategy>? strategies})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategies → List<AppendStrategy>
final

Methods

execute(AppendRequest request) → AppendResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
undo(AppendRequest request) → AppendResult

Operators

operator ==(Object other) → bool
The equality operator.
inherited