CliProgressReporter class

Implemented types

Constructors

CliProgressReporter({bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

completed() → void
override
failed(String error) → void
override
info(String message) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(ProgressReport report) → void
override
started(String message, int totalSteps) → void
override
toString() String
A string representation of this object.
inherited
update(String currentStep) → void
override
warning(String message) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited