CreateParams<T> class

Inheritance
Available extensions
Annotations
  • @JsonSerializable(explicitToJson: true, checked: true, genericArgumentFactories: true)

Constructors

CreateParams({Map<String, dynamic>? params, required T data})
const
CreateParams.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

data → T
final
hashCode int
The hash code for this object.
no setteroverride
hasParams bool

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
noParams bool

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
params Map<String, dynamic>?
final
paramsRequired Map<String, dynamic>

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareToCreateParams(CreateParams other) Map<String, dynamic>

Available on CreateParams, provided by the CreateParamsCompareE extension

compareToParams(Params other) Map<String, dynamic>

Available on Params, provided by the ParamsCompareE extension

copyWith({Map<String, dynamic>? params, T? data}) CreateParams
copyWithCreateParams({Map<String, dynamic>? params, T? data}) CreateParams
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithCreateParams([CreateParamsPatch? patchInput]) CreateParams
toJson(Object? toJsonT(T value)) Map<String, dynamic>

Available on CreateParams<T>, provided by the CreateParamsSerialization extension

toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override