CreateParamsPatch class

Inheritance

Constructors

CreateParamsPatch()

Properties

hashCode int
The hash code for this object.
no setterinherited
patchMap Map<CreateParams$, dynamic>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTo(CreateParams entity) CreateParams
Applies this patch to the given entity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toPatch() Map<CreateParams$, dynamic>
inherited
toString() String
A string representation of this object.
inherited
withData(dynamic value) CreateParamsPatch
withParams(Map<String, dynamic>? value) CreateParamsPatch

Operators

operator ==(Object other) bool
The equality operator.
inherited