DefaultFileSystem class

Implemented types

Constructors

DefaultFileSystem({String? root})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
root → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDir(String path, {bool recursive = false}) → Future<void>
override
delete(String path) → Future<void>
override
exists(String path) → Future<bool>
override
existsSync(String path) → bool
override
isDirectory(String path) → Future<bool>
override
isDirectorySync(String path) → bool
override
list(String path, {bool recursive = false}) → Future<List<String>>
override
listSync(String path, {bool recursive = false}) → List<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String path) → Future<String>
override
readSync(String path) → String
override
resolve(String path) → String
toString() → String
A string representation of this object.
inherited
watch(String path) → Stream<String>
override
write(String path, String content) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited