ExportAppendStrategy class

Implemented types

Constructors

ExportAppendStrategy({AstHelper helper = const AstHelper()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
helper AstHelper
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(AppendRequest request) AppendResult
override
canHandle(AppendRequest request) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
undo(AppendRequest request) AppendResult
override

Operators

operator ==(Object other) bool
The equality operator.
inherited