FieldSpec class

Specification for a single field in an entity.

Constructors

FieldSpec({required String name, required String dartType, required bool isNullable, required bool isList, String? description, String? referencedEntity, String? referencedEnum})
const

Properties

dartType → String
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isList → bool
final
isNullable → bool
final
name → String
final
referencedEntity → String?
final
referencedEnum → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited