GenerationContext class

Encapsulates state and dependencies for a single generation session.

Provides access to configuration, file system abstraction, state store, and progress reporting across all plugins.

Constructors

GenerationContext({required GeneratorConfig config, required String outputDir, required bool dryRun, required bool force, required bool verbose, required FileSystem fileSystem, required ContextStore store, required ProgressReporter progress})
GenerationContext.create({required GeneratorConfig config, String outputDir = 'lib/src', bool dryRun = false, bool force = false, bool verbose = false, String? root, ProgressReporter? progressReporter})
factory

Properties

config → GeneratorConfig
final
dryRun → bool
final
fileSystem → FileSystem
final
force → bool
final
hashCode → int
The hash code for this object.
no setterinherited
outputDir → String
final
progress → ProgressReporter
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → ContextStore
final
verbose → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited