GenerationResult class

Aggregated generation result for a single source file.

Constructors

GenerationResult({required String filePath})

Properties

elements List<_AnnotatedElement>
no setter
filePath String
final
hasCode bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(MethodAST method, ZorphyContext context) → void
generatePartFile() String
Generate the complete .g.dart part file as formatted Dart code.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited