GqlConstStringDetector class

Detects v5-style const-string GraphQL documents in Dart source files.

Inheritance

Constructors

GqlConstStringDetector()

Properties

detectorId → String
no setteroverride
displayName → String
no setteroverride
globs → List<String>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(String projectDir) → Future<DetectorResult>
override
lineNumberAt(String content, int offset) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFile(String absolutePath) → String?
inherited
relativePathOf(String absolute, String base) → String
inherited
shouldScan(String relativePath) → bool
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited