GqlTypeRef class

Represents a GraphQL type reference, which can be nested for NON_NULL/LIST wrappers.

Constructors

GqlTypeRef({required GqlTypeKind kind, String? name, GqlTypeRef? ofType})
const
GqlTypeRef.fromJson(Map<String, dynamic>? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isList bool
Whether this type is a list.
no setter
isNonNull bool
Whether this type is non-null (required).
no setter
kind GqlTypeKind
final
listElementType GqlTypeRef?
Returns the element type if this is a list, otherwise null.
no setter
name String?
final
namedType GqlTypeRef
Returns the innermost named type, unwrapping NON_NULL and LIST wrappers.
no setter
ofType GqlTypeRef?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited