GraphQLClientFactory class

Factory that assembles a GraphQLClient from GraphQLClientConfig.

Links are chained in order:

  1. HttpLink — HTTP transport for queries and mutations (headers applied via defaultHeaders).
  2. WebSocketLink — (optional) WebSocket transport for subscriptions, routed via Link.split on subscription operations.

Constructors

GraphQLClientFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(GraphQLClientConfig config) GraphQLClientBuildResult
Build a GraphQLClient from config.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited