GraphQLInterfaceType class

Interface type.

Inheritance

Constructors

GraphQLInterfaceType({required String name, required List<GraphQLField> fields, List<String> possibleTypes = const []})
const

Properties

dartType → String
Dart type string for code generation.
no setteroverride
fields → List<GraphQLField>
final
hashCode → int
The hash code for this object.
no setterinherited
innerType → GraphQLType
The inner type (unwrapped from List or NonNull).
no setterinherited
isList → bool
Whether this type is a list (wrapped in []).
no setterinherited
isNonNull → bool
Whether this type is non-null (wrapped in !).
no setterinherited
kind → GraphQLTypeKind
finalinherited
name → String
finalinherited
possibleTypes → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited