HiveCipher class abstract

Abstract cipher can be implemented to customize encryption.

Constructors

HiveCipher()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateKeyCrc() → int
Calculate a hash of the key. Make sure to use a secure hash.
decrypt(Uint8List inp, int inpOff, int inpLength, Uint8List out, int outOff) → int
Decrypt the given bytes.
encrypt(Uint8List inp, int inpOff, int inpLength, Uint8List out, int outOff) → int
Encrypt the given bytes.
maxEncryptedSize(Uint8List inp) → int
The maximum size the input can have after it has been encrypted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited