InList<TEntity, TValue> class

In list filter

Inheritance
Available extensions

Constructors

InList(Field<TEntity, TValue> field, List<TValue> value)
Creates a filter that matches when field is in value.
const

Properties

field Field<TEntity, TValue>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<TValue>
final

Methods

matches(TEntity item) bool
Returns true when the field value is contained in value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Not<TEntity>

Available on Filter<TEntity>, provided by the FilterOps extension

Negates this filter.
toJson() Map<String, dynamic>
Serializes the inclusion predicate to JSON.
override
toListQuery({String? search, Sort<T>? sort, int? limit, int? offset, Map<String, dynamic>? params}) ListQueryParams<T>

Available on Filter<T>, provided by the FilterToListQueryExtension extension

Converts this filter to a ListQueryParams object.
toQuery({Map<String, dynamic>? params}) QueryParams<T>

Available on Filter<T>, provided by the FilterToQueryExtension extension

Converts this filter to a QueryParams object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited