ListQueryParams<T> class

Inheritance
Available extensions
Annotations
  • @JsonSerializable(explicitToJson: true, checked: true, genericArgumentFactories: true)

Constructors

ListQueryParams({Map<String, dynamic>? params, String? search, Filter<T>? filter, Sort<T>? sort, int? limit, int? offset})
const
ListQueryParams.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

filter Filter<T>?
final
filterRequired Filter<T>

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
hasFilter bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
hashCode int
The hash code for this object.
no setteroverride
hasLimit bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
hasOffset bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
hasParams bool

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
hasSearch bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
hasSort bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
limit int?
final
limitRequired int

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
noFilter bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
noLimit bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
noOffset bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
noParams bool

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
noSearch bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
noSort bool

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
offset int?
final
offsetRequired int

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
params Map<String, dynamic>?
final
paramsRequired Map<String, dynamic>

Available on Params, provided by the ParamsPropertyHelpers extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
searchRequired String

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter
sort Sort<T>?
final
sortRequired Sort<T>

Available on ListQueryParams<T>, provided by the ListQueryParamsPropertyHelpers extension

no setter

Methods

compareToListQueryParams(ListQueryParams other) Map<String, dynamic>

Available on ListQueryParams, provided by the ListQueryParamsCompareE extension

compareToParams(Params other) Map<String, dynamic>

Available on Params, provided by the ParamsCompareE extension

copyWith({Map<String, dynamic>? params, String? search, Filter<T>? filter, Sort<T>? sort, int? limit, int? offset}) ListQueryParams
copyWithField<TValue>(Field<ListQueryParams<T>, TValue> field, TValue value) ListQueryParams
Returns a copy of this entity with field set to value.
copyWithListQueryParams({Map<String, dynamic>? params, String? search, Filter<T>? filter, Sort<T>? sort, int? limit, int? offset}) ListQueryParams
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithListQueryParams([ListQueryParamsPatch? patchInput]) ListQueryParams
toCacheKey() String

Available on ListQueryParams, provided by the ListQueryParamsExtension extension

Generates a stable cache key based on query parameters. This replaces the unstable .hashCode which changes across app restarts.
toJson(Object? toJsonT(T value)) Map<String, dynamic>

Available on ListQueryParams<T>, provided by the ListQueryParamsSerialization extension

toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override