MergeMode enum

Controls how zorphy regenerates output files.

  • smart: Parse existing file, merge intelligently (default). Preserves user edits in non-generated regions.
  • force: Overwrite the entire file (current build_runner behavior).

This is the canonical MergeMode definition used by both the annotation package and zorphy's merge engine (MergeOrchestrator).

Inheritance
Available extensions

Values

smart → const MergeMode

Parse existing file, merge intelligently (default).

force → const MergeMode

Overwrite the entire file (current build_runner behavior).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MergeMode>
A constant List of the values in this enum, in order of their declaration.