MigrationFinding class

A single finding from a v5 pattern scan.

Annotations

Constructors

MigrationFinding({required String message, required String filePath, required int line, required String ruleId, required MigrationSeverity severity, String? suggestion})
const

Properties

filePath String
Absolute or project-relative file path.
final
hashCode int
The hash code for this object.
no setterinherited
line int
1-based line number in filePath. Zero if not applicable.
final
message String
Human-readable description of the finding.
final
ruleId String
Machine-readable rule ID, e.g. v5_gql_const_string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity MigrationSeverity
Severity of this finding.
final
suggestion String?
Suggested fix description. May be null when no automatic fix is available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited