Partial<T> typedef

Partial<T> = Map<String, dynamic>

A type alias for partial entity data.

In Dart, this is represented as a Map where keys are field names and values are the new values for those fields.

Implementation

typedef Partial<T> = Map<String, dynamic>;