ProgressReport class

Constructors

ProgressReport({required String message, required int percent, required String? currentStep, required int totalSteps, required int completedSteps, required ProgressEvent event})
const
ProgressReport.completed()
const
ProgressReport.failed(String error)
const
ProgressReport.info(String message)
const
ProgressReport.started(String message, int totalSteps)
const
ProgressReport.warning(String message)
const

Properties

completedSteps int
final
currentStep String?
final
event ProgressEvent
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
percent int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalSteps int
final

Methods

nextStep(String step) ProgressReport
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited