QueryParamsFields<T> class abstract final

Field descriptors for QueryParams query construction

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

filter<T>() → Field<QueryParams<T>, Filter<T>?>
params<T>() → Field<QueryParams<T>, Map<String, dynamic>?>