QueryParamsPatch class

Inheritance

Constructors

QueryParamsPatch()

Properties

hashCode → int
The hash code for this object.
no setterinherited
patchMap → Map<QueryParams$, dynamic>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTo(QueryParams entity) → QueryParams
Applies this patch to the given entity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toPatch() → Map<QueryParams$, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
withFilter(dynamic value) → QueryParamsPatch
withParams(Map<String, dynamic>? value) → QueryParamsPatch

Operators

operator ==(Object other) → bool
The equality operator.
inherited