RetryGenerator class

Generates lib/src/middleware/zfa_retry.g.dart from collected @Retry annotation metadata.

Constructors

RetryGenerator({String packageName = 'zuraffa'})

Properties

hasEntries bool
no setter
hashCode int
The hash code for this object.
no setterinherited
packageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRetryEntry({required String className, required String methodName, required String importUri, required String returnType, required List<ParameterInfo> parameters, required int attempts, required BackoffStrategy backoff, required int maxDelayMs, required int baseDelayMs, int? maxCumulativeMs, required List<String> retryOn}) → void
generate() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited