SchemaParser class

Parses a GraphQL introspection JSON response into a GraphQLSchema.

final json = jsonDecode(await File('schema.json').readAsString());
final schema = SchemaParser.parse(json);
final productType = schema.getType('Product');

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Map<String, dynamic> introspectionJson) GraphQLSchema