SourceLocation class

Location within a source file for precise error reporting.

Annotations

Constructors

SourceLocation({required String filePath, required int line, required int column, int? offset})
const

Properties

column int
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
offset int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited