UiNodeDefinition class

A node definition in the vocabulary.

Constructors

UiNodeDefinition({required String name, required String category, required Map<String, UiPropDefinition> props, required UiChildrenConstraint children, bool isComposite = false})
const

Properties

category → String
layout | content | input | feedback | composite ...
final
children → UiChildrenConstraint
final
hashCode → int
The hash code for this object.
no setterinherited
isComposite → bool
final
name → String
Vocabulary key, e.g. card (snake_case).
final
props → Map<String, UiPropDefinition>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited