UseCaseBinding class

Metadata for a UseCase → slice binding.

Constructors

UseCaseBinding({required String sliceKey, required String useCaseFieldName, required String paramsConstructor, required String returnType, bool cacheable = false})

Properties

cacheable bool
Whether this slice should be bound to the CacheObserver for automatic cross-view state synchronization. Set when the underlying entity is @Cacheable.
final
hashCode int
The hash code for this object.
no setterinherited
paramsConstructor String
final
returnType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliceKey String
final
useCaseFieldName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited