ValidationError class

A validation error with precise location and severity.

Constructors

ValidationError({required String message, String? location, List<String>? path, ValidationSeverity severity = ValidationSeverity.error})

Properties

hashCode int
The hash code for this object.
no setterinherited
location String?
final
message String
final
path List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ValidationSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited