VpcPatterns class

Constructors

VpcPatterns()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

controllerClass({required String className, String? baseClass, Iterable<Field> fields = const [], Iterable<Method> methods = const [], Iterable<Constructor> constructors = const []}) → Class
presenterClass({required String className, String? baseClass, Iterable<Field> fields = const [], Iterable<Method> methods = const []}) → Class
stateClass({required String className, Iterable<Field> fields = const [], Iterable<Constructor> constructors = const []}) → Class