ActionRouter class abstract
Interface the UiRenderTool uses to deliver routed SemanticActions back to the agent (FR-004). Implementations translate to whatever the agent runtime supports (tool result, steering message, etc.).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deliver(
SemanticAction action) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited