AgentRuntimePlugin class

The runtime module plugin that assembles the tool registry, wires the kernel, and manages the agent lifecycle (issue #386).

Constructors

AgentRuntimePlugin({List<McpToolProvider>? spiProviders, List<McpTool> usecaseTools = const <McpTool>[], List<RemoteMcpServer> remoteServers = const <RemoteMcpServer>[], StatefulAgent? statefulAgent, LlmClient? llmClient, FileStateStorage? stateStorage, List<AgentHook> hooks = const <AgentHook>[], String playbook = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
kernel → AgentKernel
The wired kernel (FR-005).
no setter
registry → McpToolRegistry
The assembled tool registry (FR-003).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
status() KernelStatus
Returns the kernel status (FR-011).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited