AgentState class

Per-mission session state (FR-009).

Constructors

AgentState({required String missionId, List<String> steps = const <String>[]})

Properties

hashCode → int
The hash code for this object.
no setterinherited
missionId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps → List<String>
final

Methods

copyWith({List<String>? steps}) → AgentState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → AgentState