ArtifactReference class

A compact reference to an externally stored large result (FR-010).

Constructors

ArtifactReference({required String uri, required int size, required String sha256, bool truncated = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256 → String
final
size → int
final
truncated → bool
final
uri → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hashOf(Object? payload) → String
Computes the SHA-256 hash of payload.