CapturingActionRouter class

In-memory ActionRouter capturing delivered actions for test inspection.

Implemented types

Constructors

CapturingActionRouter()

Properties

delivered → List<SemanticAction>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deliver(SemanticAction action) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited