InMemoryFileStateStorage class

In-memory FileStateStorage used for tests and as a no-op fallback when no real storage is configured.

Implemented types

Constructors

InMemoryFileStateStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasStateFor(String missionId) bool
Whether missionId has persisted state.
load(String missionId) Future<AgentState?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(AgentState state) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited