MissionEventToolCallStart class final

Inheritance

Constructors

MissionEventToolCallStart(String missionId, String toolName, Map<String, Object?> args)

Properties

args → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
missionId → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited