ToolCallContext class

Context for a tool call passed to AgentHook.beforeToolCall.

Constructors

ToolCallContext({required String missionId, required String toolName, required Map<String, Object?> args})

Properties

args → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
missionId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited