toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer('UiNode($type');
  if (styleToken != null) buf.write(' style=$styleToken');
  if (actionId != null) buf.write(' action=$actionId');
  if (actionTier != null) buf.write(' tier=$actionTier');
  if (props.isNotEmpty) buf.write(' props=$props');
  if (children.isNotEmpty) buf.write(' children=${children.length}');
  buf.write(')');
  return buf.toString();
}