UiRenderEventInteraction class final

A user interaction has been captured on a rendered tree (FR-004).

Inheritance

Constructors

UiRenderEventInteraction(SemanticAction action)
const

Properties

action → SemanticAction
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited