BehaviorResult class final
The result of one scenario behavior execution.
Constructors
Properties
- attempts → int
-
final
- behavior → String
-
final
- detail → String
-
final
- expectedRed → bool
-
Whether the behavior was declared
expect: red(the honest failure-surface class — the failure-storm behaviors).final -
failureLedger
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passed → bool
-
Whether the behavior's outcome matched its declared expectation
(
expect: greenlanded green,expect: redlanded red).final - result → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- succeeded → bool
-
The raw outcome (green = the operation succeeded).
final
- virtualElapsedMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited