EntityFixtures class final
Loads committed per-entity fixture records for simulation boot.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
{required String fixturesDir, required String entity}) → List< Map< String, dynamic> > -
Loads the fixture records for
entity, failing fast. -
loadAll(
{required String fixturesDir, required Iterable< String> entities}) → Map<String, List< Map< >String, dynamic> > -
Loads the fixture records for every
entitiesentry, failing fast with SimulationFixtureError on the first unusable file. -
pathFor(
{required String fixturesDir, required String entity}) → String -
The fixture file for
entityinsidefixturesDir.