SimulationBoot class final
Boots the app end-to-end on certified mocks.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
runApp(
{required ZuraffaContainer container, required String featureDir, Set< String> entities = const {}, List<SocketLane> whitelist = const [], bool simulation = kSimulationMode}) → Future<SimulationBootReport> -
Runs the simulation boot sequence for the app rooted at
container.