WorldDiffRow class final
One behavior's differential comparison row.
Constructors
Properties
- behavior → String
-
final
- clazz → DiffClass
-
final
- detail → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payloadsEqual → bool
-
Whether both lanes' result payloads are canonically equal.
final
- realPassed → bool
-
The behavior's verdict against the real-adapter harness.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worldPassed → bool
-
The behavior's verdict inside the world binding.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited