WorldMethodProof class final

One method's proof outcome.

Constructors

WorldMethodProof({required String touchpoint, required String method, required bool satisfied, required String evidence})
const

Properties

evidence String
What the invocation proved (shape, adapter dispatch, corpus).
final
hashCode int
The hash code for this object.
no setterinherited
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satisfied bool
final
touchpoint String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited