ContractPlatformRow class

platformRows[] — one view's adaptive-slot declaration per platform.

Constructors

ContractPlatformRow({required String view, required bool mobile, required bool ios, required bool android, required bool macos})
const

Properties

android bool
final
hashCode int
The hash code for this object.
no setteroverride
ios bool
final
macos bool
final
mobile bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fields → const List<SkinContractFieldSpec>