ContractState class
states[] — one view's declared state handling.
Constructors
- ContractState({required String view, required bool loading, required String error, required bool empty})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fields
→ const List<
SkinContractFieldSpec>