SkinContractFieldSpec class

One field of a contract class, shared by the parser and the schema generator.

Constructors

SkinContractFieldSpec(String name, SkinContractFieldType type, {bool required = true, List<String>? values, String? pattern})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
pattern String?
A regex the string value must match, when applicable.
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SkinContractFieldType
final
values List<String>?
Allowed values (enum constraint), when the field is an enum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited