SkinContractRow class
Constructors
- SkinContractRow({required String id, required String requirement, required SkinContractCheck check})
-
Creates a row from a raw check closure.
const
- SkinContractRow.anchorExists({required String id, required String anchor, SkinTargetPlatform? platform})
-
A row requiring the typed anchor
anchor(azfa:contractId) to be present in the live tree.factory - SkinContractRow.progressIndicator({required String id, SkinTargetPlatform? platform})
-
A row requiring a progress indicator (loading scrim) on screen.
factory
- SkinContractRow.textRenders({required String id, required String text, SkinTargetPlatform? platform})
-
A row requiring
textto render in the live tree.factory
Properties
- check → SkinContractCheck
-
The pure check over the audited facts.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The row's id — the
[bracketed]part of the banner line.final - requirement → String
-
The human requirement — what the banner shows after the id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluate(
TreeFacts facts) → bool -
Runs the check against
facts. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited