StateBinding class

One view's declared state handling, from contract.states.

Constructors

StateBinding({required String view, required StateErrorKind error, required bool empty})
const

Properties

empty bool
final
error StateErrorKind
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited