CheckpointMessage class
Agent ↔ host: save/restore session state.
- Inheritance
-
- Object
- ZapMessage
- CheckpointMessage
Constructors
Properties
- at → String?
-
final
- digest → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Envelope: message id.
finalinherited
- kind → String
-
save|restore(requests) /saved|restored(replies).final - missionId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateId → String?
-
final
- steps → int?
-
final
- ts → String
-
Envelope: ISO-8601 UTC timestamp.
finalinherited
- type → String
-
The wire type of this message.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Wire form with stable key order (
zapfirst — the envelope reads top-down).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValidated(
Map< String, Object?> json) → CheckpointMessage