MissionEnvelope class
Agent → host: request work under budget and policy.
- Inheritance
-
- Object
- ZapMessage
- MissionEnvelope
Constructors
Properties
- agent → String
-
final
- feature → String?
-
final
- goal → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Envelope: message id.
finalinherited
- maxSteps → int
-
Session step budget — FIXED by the first mission.
final
- missionId → String
-
final
- riskTier → String
-
standard|elevated|admin.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
MissionStep> -
final
-
toolAllowlist
→ List<
String> -
Allowed executables (session policy).
final
- ts → String
-
Envelope: ISO-8601 UTC timestamp.
finalinherited
- type → String
-
The wire type of this message.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Wire form with stable key order (
zapfirst — the envelope reads top-down).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValidated(
Map< String, Object?> json) → MissionEnvelope