ZapCheck class

One receipt check (mission-schema, budget, ...).

Constructors

ZapCheck({required String name, required bool ok, String? detail})
const
ZapCheck.fromJson(Map<String, Object?> json)
factory

Properties

detail String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
ok bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited