Runs the ZAP conformance suite.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
run(
{String? driftDir}) → Future< ZapConformanceReport> -
Runs all checks.
driftDir, when given, adds the published-contract drift gate over<driftDir>/schemas/*.schema.jsonand<driftDir>/golden/*.golden.json.