ZapMessage class sealed
The sealed ZAP message family.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Envelope: message id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ts → String
-
Envelope: ISO-8601 UTC timestamp.
final
- type → String
-
The wire type of this message.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Wire form with stable key order (
zapfirst — the envelope reads top-down). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, Object?> json) → ZapMessage -
Parses
json(already decoded) into a typed ZapMessage.