ZapSchema class abstract final

Access to the five ZAP schemas (draft-07 maps).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

all Map<String, Map<String, Object?>>
All five schemas keyed by type (defensive copies of the maps).
no setter
types List<String>
The published wire types, in contract order.
no setter

Static Methods

forType(String type) Map<String, Object?>
The schema for type; throws ArgumentError for unknown types.