ZapSchemaException class
Thrown when a message fails structural validation.
- Implemented types
- Available extensions
Constructors
-
ZapSchemaException(String message, List<
ZapValidationIssue> issues, {String? classification})
Properties
- classification → String?
-
'schema'for structural violations,'version'for azapversion the host does not speak.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
ZapValidationIssue> -
The validator's path-precise issues.
final
- message → String
-
Human summary (
'mission rejected: 3 schema violations').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFailure(
[StackTrace? stackTrace]) → AppFailure -
Available on Exception, provided by the ExceptionToFailure extension
Convert this exception to an AppFailure -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited