ZapStepRun class

The result of executing one mission step.

Constructors

ZapStepRun({required String stepId, required String phase, required String command, required int exit, required String digest, required String at, required int durationMs, required String output})
const

Properties

at String
ISO-8601 UTC of completion.
final
command String
final
digest String
sha256 hex over the FULL captured output.
final
durationMs int
final
exit int
final
hashCode int
The hash code for this object.
no setterinherited
output String
final
phase String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

digestOf(List<int> bytes) String
The certified digest of bytes — one rule, one place.