$InitializationParams class abstract
Parameters for initializing a repository or data source.
Constructors
- $InitializationParams()
-
const
Properties
- credentials → $Credentials?
-
Credentials for authentication during initialization.
no setter
- forceRefresh → bool?
-
Whether to bypass cached state and force a fresh initialization.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ Map<
String, dynamic> ? -
Optional additional parameters.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → $Settings?
-
Custom settings for the initialization process.
no setter
- timeout → Duration
-
How long to wait for the app to initialize before timing out.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited