AgentRiskTier enum
Agent-centric architecture annotations for zorphy.
These annotations let developers declaratively control how zuraffa's
AgentPlugin exposes entities/usecases as MCP tools. Annotations
compile into an AgentDirective const in the generated .zorphy.dart
file, which AgentPlugin consumes at analysis time.
See: https://github.com/arrrrny/zorphy/issues/114 Risk tier for agent-exposed tools.
Values
- safe → const AgentRiskTier
- confirm → const AgentRiskTier
- admin → const AgentRiskTier
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AgentRiskTier> - A constant List of the values in this enum, in order of their declaration.