AlwaysMatch<TEntity> class
A filter that always evaluates to true.
- Inheritance
- Available extensions
Constructors
- AlwaysMatch()
-
Creates a filter that matches any input.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
matches(
TEntity item) → bool -
Always returns true for any
item.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Not< TEntity> -
Available on Filter<
Negates this filter.TEntity> , provided by the FilterOps extension -
toJson(
) → Map< String, dynamic> -
Returns an empty JSON representation.
override
-
toListQuery(
{String? search, Sort< T> ? sort, int? limit, int? offset, Map<String, dynamic> ? params}) → ListQueryParams<T> -
Available on Filter<
Converts this filter to a ListQueryParams object.T> , provided by the FilterToListQueryExtension extension -
toQuery(
{Map< String, dynamic> ? params}) → QueryParams<T> -
Available on Filter<
Converts this filter to a QueryParams object.T> , provided by the FilterToQueryExtension extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited