BenchmarkRegistry class abstract
Central registry for discovering and managing registered scenarios (FR-002).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Removes every registration (test support).
-
get(
String id) → Future< BenchmarkContract?> -
Returns the scenario registered under
id, ornull. -
getAll(
) → Future< List< BenchmarkContract> > - Returns all registered scenarios.
-
getByTags(
List< String> tags) → Future<List< BenchmarkContract> > -
Returns scenarios matching any of
tags. -
has(
String id) → Future< bool> -
Whether a scenario is registered under
id. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
BenchmarkContract scenario) → Future< Result< void, BenchmarkRegistryError> > -
Registers
scenario. -
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String id) → Future< Result< void, BenchmarkRegistryError> > -
Unregisters the scenario with
id.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited