BenchmarkRegistryError class
A registry failure: machine-readable code plus a human message.
Constructors
- BenchmarkRegistryError(BenchmarkRegistryErrorCode code, String message)
-
Creates a registry error.
const
Properties
- code → BenchmarkRegistryErrorCode
-
Machine-readable error code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited