CommandArgument class
A positional argument declaration.
- Annotations
Constructors
- CommandArgument({required String name, String help = '', bool required = false, bool multiple = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- help → String
-
Help text for the argument.
final
- multiple → bool
-
Whether the argument accepts multiple values (variadic).
final
- name → String
-
The argument name as shown in help.
final
- required → bool
-
Whether the argument is required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited