CredentialsPatch class
- Inheritance
-
- Object
- PatchBase<
Credentials, Credentials$> - CredentialsPatch
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
patchMap
→ Map<
Credentials$, dynamic> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyTo(
Credentials entity) → Credentials -
Applies this patch to the given entity
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toPatch(
) → Map< Credentials$, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withParams(
Map< String, dynamic> ? value) → CredentialsPatch
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited