EntityGenerator class
Generates zorphy entity classes from GraphQL OBJECT types.
final gen = EntityGenerator(typeMapper: mapper);
final code = gen.generate(schema.getType('Product') as GraphQLObjectType);
Constructors
- EntityGenerator({required TypeMapper typeMapper, bool includeFromJson = true, bool includeToJson = true})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeFromJson → bool
-
final
- includeToJson → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeMapper → TypeMapper
-
final
Methods
-
generate(
GraphQLObjectType objectType) → String -
Generate a complete entity file for
objectType. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited