FileGeneratorPlugin class abstract
A plugin that generates files.
- Implementers
Constructors
Properties
-
capabilities
→ List<
ZuraffaCapability> -
List of capabilities exposed by this plugin.
no setterinherited
- configKey → String?
-
The key in .zfa.json that enables this plugin by default (e.g., 'diByDefault').
no setterinherited
- configSchema → JsonSchema
-
JSON Schema for this plugin's configuration.
no setterinherited
-
dependsOn
→ List<
String> -
List of plugin IDs that must run BEFORE this plugin.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for the plugin (e.g., 'usecase', 'di').
no setterinherited
- name → String
-
Human-readable name of the plugin.
no setterinherited
-
runAfter
→ List<
String> -
List of plugin IDs that this plugin should run AFTER, if they are present.
(Like dependsOn, but doesn't force the other plugin to be active).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Semantic version of the plugin.
no setterinherited
Methods
-
afterGenerate(
PluginContext context) → Future< void> -
Hook called after generation completes successfully.
inherited
-
beforeGenerate(
PluginContext context) → Future< void> -
Hook called before generation starts.
inherited
-
generate(
GeneratorConfig config) → Future< List< GeneratedFile> > - Legacy generation method for backward compatibility.
-
generateWithContext(
PluginContext context) → Future< List< GeneratedFile> > -
Generates files based on the provided
context. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
PluginContext context, Object error, StackTrace stackTrace) → Future< void> -
Hook called if an error occurs during generation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
PluginContext context) → Future< ValidationResult> -
Validates the plugin configuration against the
context.inherited -
validateLegacy(
GeneratorConfig config) → Future< ValidationResult> -
Legacy validation method.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited