FileSystem class abstract

Implementers

Constructors

FileSystem()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDir(String path, {bool recursive = false}) Future<void>
delete(String path) Future<void>
exists(String path) Future<bool>
existsSync(String path) bool
isDirectory(String path) Future<bool>
isDirectorySync(String path) bool
list(String path, {bool recursive = false}) Future<List<String>>
listSync(String path, {bool recursive = false}) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String path) Future<String>
readSync(String path) String
toString() String
A string representation of this object.
inherited
watch(String path) Stream<String>
write(String path, String content) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({String? root}) FileSystem