GqlTypeDef class
Represents a GraphQL type definition.
Constructors
-
GqlTypeDef({required String name, required GqlTypeKind kind, String? description, List<
GqlField> ? fields, List<GqlField> ? inputFields, List<GqlEnumValue> ? enumValues, List<String> ? interfaces, List<String> ? possibleTypes}) -
const
-
GqlTypeDef.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
final
-
enumValues
→ List<
GqlEnumValue> ? -
final
-
fields
→ List<
GqlField> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFields
→ List<
GqlField> ? -
final
-
interfaces
→ List<
String> ? -
Interface names an OBJECT type implements (introspection
interfaces). Null when the server response did not include the key.final - isBuiltIn → bool
-
Whether this is a built-in type (name starts with
__).no setter - isEnum → bool
-
Whether this is an ENUM type.
no setter
- isInputObject → bool
-
Whether this is an INPUT_OBJECT type.
no setter
- isInterface → bool
-
Whether this is an INTERFACE type.
no setter
- isObject → bool
-
Whether this is an OBJECT type.
no setter
- isUnion → bool
-
Whether this is a UNION type.
no setter
- kind → GqlTypeKind
-
final
- name → String
-
final
-
possibleTypes
→ List<
String> ? -
Member type names for UNION / INTERFACE types (introspection
possibleTypes). Null when the server response did not include the key. Spec 037: parsed additively — older consumers ignore it.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited