GraphQLClientConfig class
Configuration for assembling a GraphQLClient.
// .zfa.json
{
"graphql": {
"endpoint": "https://api.example.com/graphql",
"subscriptions": true,
"wsEndpoint": "wss://api.example.com/graphql",
"headers": {
"vendure-token": "{{VENDURE_TOKEN}}"
}
}
}
Constructors
-
GraphQLClientConfig({required String endpoint, bool subscriptions = false, String? wsEndpoint, Map<
String, String> headers = const {}, Client? httpClient}) -
const
-
GraphQLClientConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endpoint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- httpClient → Client?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptions → bool
-
final
- wsEndpoint → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited