GraphQLEnumType class
Enum type.
- Inheritance
-
- Object
- GraphQLType
- GraphQLEnumType
Constructors
-
GraphQLEnumType({required String name, required List<
String> values}) -
const
Properties
- dartType → String
-
Dart type string for code generation.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerType → GraphQLType
-
The inner type (unwrapped from List or NonNull).
no setterinherited
- isList → bool
-
Whether this type is a list (wrapped in
[]).no setterinherited - isNonNull → bool
-
Whether this type is non-null (wrapped in
!).no setterinherited - kind → GraphQLTypeKind
-
finalinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited