GraphQLSchema class

Parsed GraphQL schema with type lookup.

Constructors

GraphQLSchema({required Map<String, GraphQLType> types, String? queryTypeName, String? mutationTypeName, String? subscriptionTypeName})

Properties

hashCode int
The hash code for this object.
no setterinherited
mutationTypeName String?
final
queryTypeName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionTypeName String?
final
types Map<String, GraphQLType>
final

Methods

getEnumTypes() List<GraphQLEnumType>
getInputTypes() List<GraphQLInputObjectType>
getMutationType() GraphQLObjectType?
getObjectTypes() List<GraphQLObjectType>
getQueryType() GraphQLObjectType?
getSubscriptionType() GraphQLObjectType?
getType(String name) GraphQLType?
getUnionTypes() List<GraphQLUnionType>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited