ListQueryParams<T> class
- Inheritance
- Available extensions
- Annotations
-
- @JsonSerializable(explicitToJson: true, checked: true, genericArgumentFactories: true)
Constructors
Properties
-
filter
→ Filter<
T> ? -
final
-
filterRequired
→ Filter<
T> -
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - hasFilter → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - hashCode → int
-
The hash code for this object.
no setteroverride
- hasLimit → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - hasOffset → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - hasParams → bool
-
Available on Params, provided by the ParamsPropertyHelpers extension
no setter - hasSearch → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - hasSort → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - limit → int?
-
final
- limitRequired → int
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - noFilter → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - noLimit → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - noOffset → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - noParams → bool
-
Available on Params, provided by the ParamsPropertyHelpers extension
no setter - noSearch → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - noSort → bool
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter - offset → int?
-
final
- offsetRequired → int
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter -
params
→ Map<
String, dynamic> ? -
final
-
paramsRequired
→ Map<
String, dynamic> -
Available on Params, provided by the ParamsPropertyHelpers extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String?
-
final
- searchRequired → String
-
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter -
sort
→ Sort<
T> ? -
final
-
sortRequired
→ Sort<
T> -
Available on ListQueryParams<
T> , provided by the ListQueryParamsPropertyHelpers extensionno setter
Methods
-
compareToListQueryParams(
ListQueryParams other) → Map< String, dynamic> -
Available on ListQueryParams, provided by the ListQueryParamsCompareE extension
-
compareToParams(
Params other) → Map< String, dynamic> -
Available on Params, provided by the ParamsCompareE extension
-
copyWith(
{Map< String, dynamic> ? params, String? search, Filter<T> ? filter, Sort<T> ? sort, int? limit, int? offset}) → ListQueryParams -
copyWithField<
TValue> (Field< ListQueryParams< field, TValue value) → ListQueryParamsT> , TValue> -
Returns a copy of this entity with
fieldset tovalue. -
copyWithListQueryParams(
{Map< String, dynamic> ? params, String? search, Filter<T> ? filter, Sort<T> ? sort, int? limit, int? offset}) → ListQueryParams -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patchWithListQueryParams(
[ListQueryParamsPatch? patchInput]) → ListQueryParams -
toCacheKey(
) → String -
Available on ListQueryParams, provided by the ListQueryParamsExtension extension
Generates a stable cache key based on query parameters. This replaces the unstable .hashCode which changes across app restarts. -
toJson(
Object? toJsonT(T value)) → Map< String, dynamic> -
Available on ListQueryParams<
T> , provided by the ListQueryParamsSerialization extension -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override