MigrationAction class
A migration action that was applied (or would be applied in dry-run).
- Annotations
Constructors
Properties
- action → String
-
created,modified, ordeleted.final - description → String
-
Human-readable description of what the action does.
final
- filePath → String
-
The file being modified or created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newContent → String?
-
The new file content (for
created/modified), or null.final - originalContent → String?
-
The original content before modification, or null.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited