NamespaceCollisionException class
Thrown when two tool sources register the same canonical name (FR-012).
- Implemented types
- Available extensions
Constructors
- NamespaceCollisionException(String canonicalName, String existing, String incoming)
Properties
- canonicalName → String
-
The canonical name (
"$namespace.$toolName") that collided.final - existing → String
-
The source that already registered the tool (e.g.
'spi:device').final - hashCode → int
-
The hash code for this object.
no setterinherited
- incoming → String
-
The source that attempted to register (e.g.
'remote:sse').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFailure(
[StackTrace? stackTrace]) → AppFailure -
Available on Exception, provided by the ExceptionToFailure extension
Convert this exception to an AppFailure -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited