NonInteractiveContextException class
A command requires interaction with the user, but stdout is piped or stdin is not a TTY (FR-009 edge case 6: non-CLI / non-interactive context).
- Inheritance
-
- Object
- CliEdgeCaseException
- NonInteractiveContextException
- Available extensions
Constructors
- NonInteractiveContextException({required String commandName, required String reason})
-
const
Properties
- code → String
-
The error code, one of the CliExitCodes vocabulary names as a string
(e.g.
'notFound','conflict'). Used in the JSON error shape'scodefield and translated to the contract exit code by CliApp.no setteroverride - commandName → String
-
The command that required interaction.
final
-
details
→ Map<
String, Object?> -
Additional context for the JSON error shape's
detailsfield.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
no setteroverride
- reason → String
-
Why the context is non-interactive (e.g.
'stdout is piped').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFailure(
[StackTrace? stackTrace]) → AppFailure -
Available on Exception, provided by the ExceptionToFailure extension
Convert this exception to an AppFailure -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited