ReferencedAppMissingException class
The owner app referenced by a cross-app invocation is not registered (FR-009 edge case 3: referenced command or app missing).
- Inheritance
-
- Object
- CliEdgeCaseException
- ReferencedAppMissingException
- Available extensions
Constructors
-
ReferencedAppMissingException({required String ownerApp, required List<
String> registeredApps}) -
const
Properties
- code → String
-
The error code, one of the CliExitCodes vocabulary names as a string
(e.g.
'notFound','conflict'). Used in the JSON error shape'scodefield and translated to the contract exit code by CliApp.no setteroverride -
details
→ Map<
String, Object?> -
Additional context for the JSON error shape's
detailsfield.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
no setteroverride
- ownerApp → String
-
The owner app that was referenced but is not registered.
final
-
registeredApps
→ List<
String> -
The list of registered owner apps, for the help hint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFailure(
[StackTrace? stackTrace]) → AppFailure -
Available on Exception, provided by the ExceptionToFailure extension
Convert this exception to an AppFailure -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited