RepositoryPatterns class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
repositoryInterface(
{required String className, required Iterable< Method> methods}) → Class -
repositoryMethod(
{required String name, required String returnType, Iterable< Parameter> parameters = const []}) → Method