RouteValidationError class
A single actionable validation failure.
Constructors
- RouteValidationError({required RouteValidationErrorCode code, required String message, String? filePath, int? line})
-
const
Properties
- code → RouteValidationErrorCode
-
final
- filePath → String?
-
Source file of the offending annotation, when known.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int?
-
Line of the offending annotation, when known.
final
- message → String
-
Human-readable, actionable message naming the offending classes/paths.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited