SortConverter class
Converter for Sort type.
Provides static methods for serializing and deserializing Zorphy Sort objects with generic-aware helpers and optional field resolution to preserve type-safety and matching behavior.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> ? json, [Map<String, Field> ? fields, FieldResolver? resolveField]) → Sort? - Deserializes a Sort from JSON with optional field resolution.
-
fromJsonTyped<
T> (Map< String, dynamic> ? json, [Map<String, Field< ? fields, FieldResolver<T, dynamic> >T> ? resolveField]) → Sort<T> ? - Deserializes a typed Sort from JSON with optional field resolution.
-
toJson(
Sort? sort) → Map< String, dynamic> ? - Serializes a Sort to JSON.
-
toJsonTyped<
T> (Sort< T> ? sort) → Map<String, dynamic> ? - Serializes a typed Sort to JSON with clearer generic context.