SourceLocation class
Location within a source file for precise error reporting.
- Annotations
Constructors
- SourceLocation({required String filePath, required int line, required int column, int? offset})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited