StreamToSignalResultAdapter<T> class
Adapter for migrating v5 Stream<Result<T, AppFailure>> use cases to v6.
Wraps a stream in a SignalResult and bridges emissions. This is a temporary migration helper — prefer native SignalResult implementations for new use cases.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
adapt<
T> (Stream< Result< stream) → SignalResult<T, AppFailure> >T> - Convert a stream to a SignalResult.