UpdateParamsPatch class
- Inheritance
-
- Object
- PatchBase<
UpdateParams, UpdateParams$> - UpdateParamsPatch
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
patchMap
→ Map<
UpdateParams$, dynamic> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyTo(
UpdateParams entity) → UpdateParams -
Applies this patch to the given entity
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toPatch(
) → Map< UpdateParams$, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withData(
dynamic value) → UpdateParamsPatch -
withId(
dynamic value) → UpdateParamsPatch -
withParams(
Map< String, dynamic> ? value) → UpdateParamsPatch
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited