AgentRuntimePlugin class
The runtime module plugin that assembles the tool registry, wires the kernel, and manages the agent lifecycle (issue #386).
Constructors
-
AgentRuntimePlugin({List<
McpToolProvider> ? spiProviders, List<McpTool> usecaseTools = const <McpTool>[], List<RemoteMcpServer> remoteServers = const <RemoteMcpServer>[], StatefulAgent? statefulAgent, LlmClient? llmClient, FileStateStorage? stateStorage, List<AgentHook> hooks = const <AgentHook>[], String playbook = ''})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
status(
) → KernelStatus - Returns the kernel status (FR-011).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited