KernelStatus class
Structured kernel status report (FR-011).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providers
→ Map<
String, String> -
Registered SPI providers keyed by namespace.
final
-
remoteServerHealth
→ Map<
String, String> -
Health check per remote MCP server (server-id → status string).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toolCountPerNamespace
→ Map<
String, int> -
Tool count per namespace (e.g.
{'device': 3, 'usecase': 5, 'remote:sse': 2}).final - totalToolCount → int
-
Total number of registered tools.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited