RemoteMcpServer class
A remote MCP server registered with the runtime plugin.
Constructors
-
RemoteMcpServer({required String id, required List<
McpTool> tools, String healthStatus = 'unknown'})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthStatus → String
-
Health status string (e.g.
'healthy','unreachable').final - id → String
-
Stable server identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
→ List<
McpTool> -
Tools contributed by this server.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited