UiRenderEventRender class final
A tree (or partial tree) has been rendered and is ready for the host UI to paint (FR-001, FR-003).
- Inheritance
-
- Object
- UiRenderEvent
- UiRenderEventRender
Constructors
- UiRenderEventRender(RenderedView view, {bool isPartial = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPartial → bool
-
truewhen this is an intermediate partial render (FR-003 acceptance 3).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- view → RenderedView
-
The rendered view, or a partial view during progressive streaming.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited